
#include <STC12C5A.H>

//=============================================================
//Define LCD PIN IO
sbit CS=P1^0;		//chip select when low
sbit DC=P1^3;		//high :data  low:command    
sbit SCL=P1^1;		//SERIAL CLOCK INPUT    
sbit SDI=P1^2;	     //SERIAL DATA INPUT/OUTPUT   
sbit RES=P2^6;		//reset


//Define key io 
sbit KEY = P2^7;  //NEXT

unsigned char USE_HORIZONTAL;   // 0,1 Vertical screen   2,3 Landscape screen


 
void lcd_Initial(void);
void Write_Cmd_Data(unsigned char);
void Write_Cmd(unsigned char);
void Write_Data(unsigned char DH,unsigned char DL);
void delayms(unsigned int tt);
void Write_Data_U16(unsigned int y);
void LCD_SetPos(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2);
void ClearScreen(unsigned int bColor);
void Draw_Circle(unsigned int x0,unsigned int y0,unsigned char r,unsigned int color);
void LCD_DrawRectangle(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2,unsigned int color);
void LCD_DrawLine(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2,unsigned int color);
void LCD_DrawPoint(unsigned int x,unsigned int y,unsigned int color);
void showzifustr(unsigned int x,unsigned int y,unsigned char *str,unsigned int dcolor,unsigned int bgcolor);
void showzifu(unsigned int x,unsigned int y,unsigned char value,unsigned int dcolor,unsigned int bgcolor);
  
unsigned int code pic[];
unsigned char code String6_12[];

//===============================================================
//clear screen  
void ClearScreen(unsigned int bColor)
{
 unsigned int i,j;
LCD_SetPos(0,0,39,160); 
 for (i=0;i<161;i++)
	{
	
	   for (j=0;j<40;j++)
	       Write_Data_U16(bColor);
	}
}


//===============================================================
//write parameter
void  Write_Cmd_Data (unsigned char CMDP)
{ unsigned char i;
 	 
    CS=0;
   	DC=1;
    for(i=0;i<8;i++)
     {  SCL=0;
        if(CMDP&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        CMDP=CMDP<<1;
     }
   	CS=1;

}


//=============================================================
//write command

void Write_Cmd(unsigned char CMD)
{ unsigned char i;
 	 
    CS=0;
   	DC=0;
    for(i=0;i<8;i++)
     {  SCL=0;
        if(CMD&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        CMD=CMD<<1;
     }
   	CS=1;


}


//==============================================================
//write  data word
void  Write_Data_U16(unsigned int y)
{
	unsigned char m,n;
	m=y>>8;
	n=y;
	Write_Data(m,n);

}


//===================================================================
//write data byte

void Write_Data(unsigned char DH,unsigned char DL)
{unsigned char i;
 	 
    CS=0;
   	DC=1;
    for(i=0;i<8;i++)
     {  SCL=0;
        if(DH&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        DH=DH<<1;
     }

    for(i=0;i<8;i++)
     {  SCL=0;
        if(DL&0x80) SDI=1;
       	else SDI=0;
       	SCL=1;
        DL=DL<<1;
     }

   	CS=1;

}



//============================================================
//delay
void delayms(unsigned int count)
{
    int i,j;                                                                                
    for(i=0;i<count;i++)                                                                    
       {
	     for(j=0;j<1000;j++);
       }                                                                                     
}


//show one Character
void showzifu(unsigned int x,unsigned int y,unsigned char value,unsigned int dcolor,unsigned int bgcolor)	
{  
	unsigned char i,j;
	unsigned char *temp=String6_12;    
    LCD_SetPos(x,y,x+7,y+11);      
	temp+=(value-32)*12;
	for(j=0;j<12;j++)
	{
		for(i=0;i<8;i++)
		{ 		     
		 	if((*temp&(1<<(7-i)))!=0)
			{
				Write_Data(dcolor>>8,dcolor);
			} 
			else
			{
				Write_Data(bgcolor>>8,bgcolor);
			}   
		}
		temp++;
	 }
}

//show String
void showzifustr(unsigned int x,unsigned int y,unsigned char *str,unsigned int dcolor,unsigned int bgcolor)	  
{  
	unsigned int x1,y1;
	x1=x;
	y1=y;
	while(*str!='\0')
	{	
		showzifu(x1,y1,*str,dcolor,bgcolor);
		x1+=7;
		str++;
	}	
}




void LCD_DrawPoint(unsigned int x,unsigned int y,unsigned int color)
{
	LCD_SetPos(x,y,x,y);
	Write_Data_U16(color);
} 

void LCD_DrawLine(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2,unsigned int color)
{
	unsigned int t; 
	int xerr=0,yerr=0,delta_x,delta_y,distance;
	int incx,incy,uRow,uCol;
	delta_x=x2-x1; 
	delta_y=y2-y1;
	uRow=x1;
	uCol=y1;
	if(delta_x>0)incx=1; 
	else if (delta_x==0)incx=0;
	else {incx=-1;delta_x=-delta_x;}
	if(delta_y>0)incy=1;
	else if (delta_y==0)incy=0;
	else {incy=-1;delta_y=-delta_x;}
	if(delta_x>delta_y)distance=delta_x;  
	else distance=delta_y;
	for(t=0;t<distance+1;t++)
	{
		LCD_DrawPoint(uRow,uCol,color);
		xerr+=delta_x;
		yerr+=delta_y;
		if(xerr>distance)
		{
			xerr-=distance;
			uRow+=incx;
		}
		if(yerr>distance)
		{
			yerr-=distance;
			uCol+=incy;
		}
	}
}



void LCD_DrawRectangle(unsigned int x1, unsigned int y1, unsigned int x2, unsigned int y2,unsigned int color)
{
	LCD_DrawLine(x1,y1,x2,y1,color);
	LCD_DrawLine(x1,y1,x1,y2,color);
	LCD_DrawLine(x1,y2,x2,y2,color);
	LCD_DrawLine(x2,y1,x2,y2,color);
}


void Draw_Circle(unsigned int x0,unsigned int y0,unsigned char r,unsigned int color)
{
	int a,b;
	a=0;b=r;	  
	while(a<=b)
	{
		LCD_DrawPoint(x0-b,y0-a,color);             //3           
		LCD_DrawPoint(x0+b,y0-a,color);             //0           
		LCD_DrawPoint(x0-a,y0+b,color);             //1                
		LCD_DrawPoint(x0-a,y0-b,color);             //2             
		LCD_DrawPoint(x0+b,y0+a,color);             //4               
		LCD_DrawPoint(x0+a,y0-b,color);             //5
		LCD_DrawPoint(x0+a,y0+b,color);             //6 
		LCD_DrawPoint(x0-b,y0+a,color);             //7
		a++;
		if((a*a+b*b)>(r*r))
		{
			b--;
		}
	}
}





//============================================================
//show picture
void show_picture(void)
{ 
	unsigned char i,j;
	unsigned int n=0;


   LCD_SetPos(0,0,39,159);
	for(j=0;j<160;j++)
	{
		for(i=0;i<40;i++)
		{
            Write_Data_U16(pic[n]<<8|pic[n+1]);
			n+=2;
	    }
	}


    return;
}


//=============================================================
//LCD Initial

void lcd_Initial(void)
{ 

	delayms(5);
	RES=0;
	delayms(10);
	RES=1;
	delayms(120); 

	Write_Cmd(0xFE);			 
	Write_Cmd(0xEF); 
 //ڲĴʹ80~8Fh
	Write_Cmd(0x80);
	Write_Cmd_Data(0xFF);
	
	Write_Cmd(0x81);
	Write_Cmd_Data(0xFF);

	Write_Cmd(0x82);
	Write_Cmd_Data(0xFF);

	Write_Cmd(0x83);
	Write_Cmd_Data(0xFF);

	Write_Cmd(0x84);			
	Write_Cmd_Data(0xFF); 

	Write_Cmd(0x85);
	Write_Cmd_Data(0xFF); 

	Write_Cmd(0x86);            
	Write_Cmd_Data(0xFF); 

	Write_Cmd(0x87);            
	Write_Cmd_Data(0xFF);

	Write_Cmd(0x88);            
	Write_Cmd_Data(0xFF);

	Write_Cmd(0x89);            
	Write_Cmd_Data(0xFF);

	Write_Cmd(0x8A);            
	Write_Cmd_Data(0xFF);

	Write_Cmd(0x8B);            
	Write_Cmd_Data(0xFF);

	Write_Cmd(0x8C);            
	Write_Cmd_Data(0xFF);

	Write_Cmd(0x8D);            
	Write_Cmd_Data(0xFF);

	Write_Cmd(0x8E);        
	Write_Cmd_Data(0xFF); 

	Write_Cmd(0x8F);     
	Write_Cmd_Data(0xFF); 

	Write_Cmd(0x3A);     
	Write_Cmd_Data(0x05);
//÷תʽ
	Write_Cmd(0xEC);     
	Write_Cmd_Data(0x11);

//VGLС
	Write_Cmd(0x7E);     
	Write_Cmd_Data(0x7a);




//޸֡Ƶ
	Write_Cmd(0x74);		
	Write_Cmd_Data(0x02);
	Write_Cmd_Data(0x0E);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x28);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);

//ڲѹ
	Write_Cmd(0x98);     
	Write_Cmd_Data(0x3E);
	Write_Cmd(0x99);     
	Write_Cmd_Data(0x3E);



//ڲporch
	Write_Cmd(0xB5);			
	Write_Cmd_Data(0x0E);
	Write_Cmd_Data(0x0E);

//gip timing start
	Write_Cmd(0x60);		
	Write_Cmd_Data(0x38);
	Write_Cmd_Data(0x09);
	Write_Cmd_Data(0x6D);
	Write_Cmd_Data(0x67);


	Write_Cmd(0x63);		
	Write_Cmd_Data(0x38);
	Write_Cmd_Data(0xAD);
	Write_Cmd_Data(0x6D);
	Write_Cmd_Data(0x67);
	Write_Cmd_Data(0x05);


	Write_Cmd(0x64);			
	Write_Cmd_Data(0x38);
	Write_Cmd_Data(0x0B);
	Write_Cmd_Data(0x70);
	Write_Cmd_Data(0xAB);
	Write_Cmd_Data(0x6D);
	Write_Cmd_Data(0x67);


	Write_Cmd(0x66);			
	Write_Cmd_Data(0x38);
	Write_Cmd_Data(0x0F);
	Write_Cmd_Data(0x70);
	Write_Cmd_Data(0xAF);
	Write_Cmd_Data(0x6d);
	Write_Cmd_Data(0x67);

	Write_Cmd(0x6A);		
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);

	Write_Cmd(0x68);
	Write_Cmd_Data(0x3B);
	Write_Cmd_Data(0x08);
	Write_Cmd_Data(0x04);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x04);
	Write_Cmd_Data(0x64);
	Write_Cmd_Data(0x67);



	Write_Cmd(0x6C);			
	Write_Cmd_Data(0x22);
	Write_Cmd_Data(0x02);
	Write_Cmd_Data(0x22);
	Write_Cmd_Data(0x02);
	Write_Cmd_Data(0x22);
	Write_Cmd_Data(0x22);
	Write_Cmd_Data(0x50);

	Write_Cmd(0x6E);	
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x07);
	Write_Cmd_Data(0x01);
	Write_Cmd_Data(0x13);
	Write_Cmd_Data(0x11);

	Write_Cmd_Data(0x0B);
	Write_Cmd_Data(0x09);
	Write_Cmd_Data(0x16);
	Write_Cmd_Data(0x15);
	Write_Cmd_Data(0x1D);
	Write_Cmd_Data(0x1E);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);

	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x1E);

	Write_Cmd_Data(0x1D);
	Write_Cmd_Data(0x15);
	Write_Cmd_Data(0x16);
	Write_Cmd_Data(0x0A);
	Write_Cmd_Data(0x0C);

	Write_Cmd_Data(0x12);
	Write_Cmd_Data(0x14);
	Write_Cmd_Data(0x02);
	Write_Cmd_Data(0x08);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x00);

//gip timing end

//ڲѹ趨ʼ
	Write_Cmd(0xA9);			
	Write_Cmd_Data(0x1B);

	Write_Cmd(0xA8);			
	Write_Cmd_Data(0x6B);

	Write_Cmd(0xA8);			
	Write_Cmd_Data(0x6D);

	Write_Cmd(0xA7);			
	Write_Cmd_Data(0x40);

	Write_Cmd(0xAD);			
	Write_Cmd_Data(0x47);


	Write_Cmd(0xAF);			
	Write_Cmd_Data(0x73);

	Write_Cmd(0xAF);			
	Write_Cmd_Data(0x73);

	Write_Cmd(0xAC);			
	Write_Cmd_Data(0x44);

	Write_Cmd(0xA3);			
	Write_Cmd_Data(0x6C);

	Write_Cmd(0xCB);			
	Write_Cmd_Data(0x00);

	Write_Cmd(0xCD);			
	Write_Cmd_Data(0x22);


	Write_Cmd(0xC2);			
	Write_Cmd_Data(0x10);

	Write_Cmd(0xC5);			
	Write_Cmd_Data(0x00);

	Write_Cmd(0xC6);			
	Write_Cmd_Data(0x0E);

	Write_Cmd(0xC7);			
	Write_Cmd_Data(0x1f);

	Write_Cmd(0xC8);			
	Write_Cmd_Data(0x0E);
//ڲѹ趨

//ѡsingle gate mode
	Write_Cmd(0xbf);			
	Write_Cmd_Data(0x00);
//SOUص
	Write_Cmd(0xF9);			
	Write_Cmd_Data(0x20);

//vregѹ
	Write_Cmd(0x9b);			
	Write_Cmd_Data(0x3b);
	Write_Cmd(0x93);
	Write_Cmd_Data(0x33);
	Write_Cmd_Data(0x7f);
	Write_Cmd_Data(0x00);

//VGH/VGL CLK7071h
	Write_Cmd(0x70);
	Write_Cmd_Data(0x0E);
	Write_Cmd_Data(0x0f);
	Write_Cmd_Data(0x03);
	Write_Cmd_Data(0x0e);
	Write_Cmd_Data(0x0f);
	Write_Cmd_Data(0x03);

	Write_Cmd(0x71);
	Write_Cmd_Data(0x0e);
	Write_Cmd_Data(0x16);
	Write_Cmd_Data(0x03);

//ڲѹ
	Write_Cmd(0x91);
	Write_Cmd_Data(0x0e);
	Write_Cmd_Data(0x09);


//vregѹ
	Write_Cmd(0xc3);
	Write_Cmd_Data(0x2c);
	Write_Cmd(0xc4);
	Write_Cmd_Data(0x1a);



//gamma F1~F3h
	Write_Cmd(0xf0);
	Write_Cmd_Data(0x51);
	Write_Cmd_Data(0x13);
	Write_Cmd_Data(0x0c);
	Write_Cmd_Data(0x06);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x2f);

	Write_Cmd(0xf2);
	Write_Cmd_Data(0x51);
	Write_Cmd_Data(0x13);
	Write_Cmd_Data(0x0c);
	Write_Cmd_Data(0x06);
	Write_Cmd_Data(0x00);
	Write_Cmd_Data(0x33);

	Write_Cmd(0xf1);
	Write_Cmd_Data(0x3c);
	Write_Cmd_Data(0x94);
	Write_Cmd_Data(0x4f);
	Write_Cmd_Data(0x33);
	Write_Cmd_Data(0x34);
	Write_Cmd_Data(0xCf);

	Write_Cmd(0xf3);
	Write_Cmd_Data(0x4d);
	Write_Cmd_Data(0x94);
	Write_Cmd_Data(0x4f);
	Write_Cmd_Data(0x33);
	Write_Cmd_Data(0x34);
	Write_Cmd_Data(0xCf);

	Write_Cmd(0x36);			
	Write_Cmd_Data(0x00);
	Write_Cmd(0x11);
	delayms(200); 
	Write_Cmd(0x29);
 	delayms(50);
}


//===============================================================
 void LCD_SetPos(unsigned int x1,unsigned int y1,unsigned int x2,unsigned int y2)
{	
 
	Write_Cmd(0x2a);                          
	Write_Cmd_Data(x1>>8);
	Write_Cmd_Data(x1);	
  	Write_Cmd_Data(x2>>8); 	  
	Write_Cmd_Data(x2);            
	Write_Cmd(0x2b);             
	Write_Cmd_Data(y1>>8);   	
	Write_Cmd_Data(y1);
  	Write_Cmd_Data(y2>>8);    
	Write_Cmd_Data(y2);
	Write_Cmd(0x2C);
	
	
}

unsigned char code String6_12[]={         
/*--   --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  !  --*/
0x00,0x00,0x20,0x20,0x20,0x20,0x20,0x20,0x00,0x20,0x00,0x00,
/*--  "  --*/
0x00,0x28,0x50,0x50,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  #  --*/
0x00,0x00,0x28,0x28,0xFC,0x28,0x50,0xFC,0x50,0x50,0x00,0x00,
/*--  $  --*/
0x00,0x20,0x78,0xA8,0xA0,0x60,0x30,0x28,0xA8,0xF0,0x20,0x00,
/*-- %  --*/
0x00,0x00,0x48,0xA8,0xB0,0x50,0x28,0x34,0x54,0x48,0x00,0x00,
/*--  &  --*/
0x00,0x00,0x20,0x50,0x50,0x78,0xA8,0xA8,0x90,0x6C,0x00,0x00,
/*--  '  --*/
0x00,0x40,0x40,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  (  --*/
0x00,0x04,0x08,0x10,0x10,0x10,0x10,0x10,0x10,0x08,0x04,0x00,
/*--  )  --*/
0x00,0x40,0x20,0x10,0x10,0x10,0x10,0x10,0x10,0x20,0x40,0x00,
/*--   *  --*/
0x00,0x00,0x00,0x20,0xA8,0x70,0x70,0xA8,0x20,0x00,0x00,0x00,
/*--   +  --*/
0x00,0x00,0x20,0x20,0x20,0xF8,0x20,0x20,0x20,0x00,0x00,0x00,
/*-  ,  --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x80,
/*--  -  --*/
0x00,0x00,0x00,0x00,0x00,0xF8,0x00,0x00,0x00,0x00,0x00,0x00,
/*--   .  --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x00,0x00,
/*--    /  --*/
0x00,0x08,0x10,0x10,0x10,0x20,0x20,0x40,0x40,0x40,0x80,0x00,
/*--   0  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x70,0x00,0x00,
/*--  1  --*/
0x00,0x00,0x20,0x60,0x20,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
/*--   2  --*/
0x00,0x00,0x70,0x88,0x88,0x10,0x20,0x40,0x80,0xF8,0x00,0x00,
/*--   3  --*/
0x00,0x00,0x70,0x88,0x08,0x30,0x08,0x08,0x88,0x70,0x00,0x00,
/*--  4  --*/
0x00,0x00,0x10,0x30,0x50,0x50,0x90,0x78,0x10,0x18,0x00,0x00,
/*--   5  --*/
0x00,0x00,0xF8,0x80,0x80,0xF0,0x08,0x08,0x88,0x70,0x00,0x00,
/*--   6  --*/
0x00,0x00,0x70,0x90,0x80,0xF0,0x88,0x88,0x88,0x70,0x00,0x00,
/*--   7  --*/
0x00,0x00,0xF8,0x90,0x10,0x20,0x20,0x20,0x20,0x20,0x00,0x00,
/*-- 8  --*/
0x00,0x00,0x70,0x88,0x88,0x70,0x88,0x88,0x88,0x70,0x00,0x00,
/*--   9  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x78,0x08,0x48,0x70,0x00,0x00,
/*--   :  --*/
0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x00,0x20,0x00,0x00,
/*--   ;  --*/
0x00,0x00,0x00,0x00,0x00,0x20,0x00,0x00,0x00,0x20,0x20,0x00,
/*--   <  --*/
0x00,0x04,0x08,0x10,0x20,0x40,0x20,0x10,0x08,0x04,0x00,0x00,
/*--  =  --*/
0x00,0x00,0x00,0x00,0xF8,0x00,0x00,0xF8,0x00,0x00,0x00,0x00,
/*--  >  --*/
0x00,0x40,0x20,0x10,0x08,0x04,0x08,0x10,0x20,0x40,0x00,0x00,
/*--  ?  --*/
0x00,0x00,0x70,0x88,0x88,0x10,0x20,0x20,0x00,0x20,0x00,0x00,
/*--   @  --*/
0x00,0x00,0x70,0x88,0x98,0xA8,0xA8,0xB8,0x80,0x78,0x00,0x00,
/*--  A  --*/
0x00,0x00,0x20,0x20,0x30,0x50,0x50,0x78,0x48,0xCC,0x00,0x00,
/*--   B  --*/
0x00,0x00,0xF0,0x48,0x48,0x70,0x48,0x48,0x48,0xF0,0x00,0x00,
/*--  C  --*/
0x00,0x00,0x78,0x88,0x80,0x80,0x80,0x80,0x88,0x70,0x00,0x00,
/*--  D  --*/
0x00,0x00,0xF0,0x48,0x48,0x48,0x48,0x48,0x48,0xF0,0x00,0x00,
/*--  E  --*/
0x00,0x00,0xF8,0x48,0x50,0x70,0x50,0x40,0x48,0xF8,0x00,0x00,
/*--   F  --*/
0x00,0x00,0xF8,0x48,0x50,0x70,0x50,0x40,0x40,0xE0,0x00,0x00,
/*--   G  --*/
0x00,0x00,0x38,0x48,0x80,0x80,0x9C,0x88,0x48,0x30,0x00,0x00,
/*--  H  --*/
0x00,0x00,0xCC,0x48,0x48,0x78,0x48,0x48,0x48,0xCC,0x00,0x00,
/*--   I  --*/
0x00,0x00,0xF8,0x20,0x20,0x20,0x20,0x20,0x20,0xF8,0x00,0x00,
/*--   J  --*/
0x00,0x00,0x7C,0x10,0x10,0x10,0x10,0x10,0x10,0x90,0xE0,0x00,
/*--   K  --*/
0x00,0x00,0xEC,0x48,0x50,0x60,0x50,0x50,0x48,0xEC,0x00,0x00,
/*--   L  --*/
0x00,0x00,0xE0,0x40,0x40,0x40,0x40,0x40,0x44,0xFC,0x00,0x00,
/*--  M  --*/
0x00,0x00,0xD8,0xD8,0xD8,0xD8,0xA8,0xA8,0xA8,0xA8,0x00,0x00,
/*--   N  --*/
0x00,0x00,0xDC,0x48,0x68,0x68,0x58,0x58,0x48,0xE8,0x00,0x00,
/*--   O  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x88,0x88,0x88,0x70,0x00,0x00,
/*--   P  --*/
0x00,0x00,0xF0,0x48,0x48,0x70,0x40,0x40,0x40,0xE0,0x00,0x00,
/*--   Q  --*/
0x00,0x00,0x70,0x88,0x88,0x88,0x88,0xE8,0x98,0x70,0x18,0x00,
/*--  R  --*/
0x00,0x00,0xF0,0x48,0x48,0x70,0x50,0x48,0x48,0xEC,0x00,0x00,
/*--   S  --*/
0x00,0x00,0x78,0x88,0x80,0x60,0x10,0x08,0x88,0xF0,0x00,0x00,
/*--   T  --*/
0x00,0x00,0xF8,0xA8,0x20,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
/*--   U  --*/
0x00,0x00,0xCC,0x48,0x48,0x48,0x48,0x48,0x48,0x30,0x00,0x00,
/*--    V  --*/
0x00,0x00,0xCC,0x48,0x48,0x50,0x50,0x30,0x20,0x20,0x00,0x00,
/*--   W  --*/
0x00,0x00,0xA8,0xA8,0xA8,0x70,0x50,0x50,0x50,0x50,0x00,0x00,
/*--    X  --*/
0x00,0x00,0xD8,0x50,0x50,0x20,0x20,0x50,0x50,0xD8,0x00,0x00,
/*--    Y  --*/
0x00,0x00,0xD8,0x50,0x50,0x20,0x20,0x20,0x20,0x70,0x00,0x00,
/*--    Z  --*/
0x00,0x00,0xF8,0x90,0x10,0x20,0x20,0x40,0x48,0xF8,0x00,0x00,
/*--   [  --*/
0x00,0x38,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x38,0x00,
/*--    \  --*/
0x00,0x40,0x40,0x40,0x20,0x20,0x10,0x10,0x10,0x08,0x00,0x00,
/*--    ]  --*/
0x00,0x70,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x70,0x00,
/*--    ^  --*/
0x00,0x20,0x50,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--   _  --*/
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFC,
/*--   `  --*/
0x00,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/*--  a  --*/
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x38,0x48,0x3C,0x00,0x00,
/*--   b  --*/
0x00,0x00,0xC0,0x40,0x40,0x70,0x48,0x48,0x48,0x70,0x00,0x00,
/*--   c  --*/
0x00,0x00,0x00,0x00,0x00,0x38,0x48,0x40,0x40,0x38,0x00,0x00,
/*--  d  --*/
0x00,0x00,0x18,0x08,0x08,0x38,0x48,0x48,0x48,0x3C,0x00,0x00,
/*--    e  --*/
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x78,0x40,0x38,0x00,0x00,
/*--   f  --*/
0x00,0x00,0x1C,0x20,0x20,0x78,0x20,0x20,0x20,0x78,0x00,0x00,
/*--   g  --*/
0x00,0x00,0x00,0x00,0x00,0x3C,0x48,0x30,0x40,0x78,0x44,0x38,
/*--    h  --*/
0x00,0x00,0xC0,0x40,0x40,0x70,0x48,0x48,0x48,0xEC,0x00,0x00,
/*--   i  --*/
0x00,0x00,0x20,0x00,0x00,0x60,0x20,0x20,0x20,0x70,0x00,0x00,
/*--   j  --*/
0x00,0x00,0x10,0x00,0x00,0x30,0x10,0x10,0x10,0x10,0x10,0xE0,
/*--   k  --*/
0x00,0x00,0xC0,0x40,0x40,0x5C,0x50,0x70,0x48,0xEC,0x00,0x00,
/*--  l  --*/
0x00,0x00,0xE0,0x20,0x20,0x20,0x20,0x20,0x20,0xF8,0x00,0x00,
/*--   m  --*/
0x00,0x00,0x00,0x00,0x00,0xF0,0xA8,0xA8,0xA8,0xA8,0x00,0x00,
/*--    n  --*/
0x00,0x00,0x00,0x00,0x00,0xF0,0x48,0x48,0x48,0xEC,0x00,0x00,
/*--    o  --*/
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x48,0x48,0x30,0x00,0x00,
/*--   p  --*/
0x00,0x00,0x00,0x00,0x00,0xF0,0x48,0x48,0x48,0x70,0x40,0xE0,
/*--  q  --*/
0x00,0x00,0x00,0x00,0x00,0x38,0x48,0x48,0x48,0x38,0x08,0x1C,
/*--    r  --*/
0x00,0x00,0x00,0x00,0x00,0xD8,0x60,0x40,0x40,0xE0,0x00,0x00,
/*--    s  --*/
0x00,0x00,0x00,0x00,0x00,0x78,0x40,0x30,0x08,0x78,0x00,0x00,
/*--   t  --*/
0x00,0x00,0x00,0x20,0x20,0x70,0x20,0x20,0x20,0x18,0x00,0x00,
/*--    u  --*/
0x00,0x00,0x00,0x00,0x00,0xD8,0x48,0x48,0x48,0x3C,0x00,0x00,
/*--   v  --*/
0x00,0x00,0x00,0x00,0x00,0xEC,0x48,0x50,0x30,0x20,0x00,0x00,
/*--   w  --*/
0x00,0x00,0x00,0x00,0x00,0xA8,0xA8,0x70,0x50,0x50,0x00,0x00,
/*--  x  --*/
0x00,0x00,0x00,0x00,0x00,0xD8,0x50,0x20,0x50,0xD8,0x00,0x00,
/*--   y  --*/
0x00,0x00,0x00,0x00,0x00,0xEC,0x48,0x50,0x30,0x20,0x20,0xC0,
/*--  z  --*/
0x00,0x00,0x00,0x00,0x00,0x78,0x10,0x20,0x20,0x78,0x00,0x00,
/* {  --*/
0x00,0x18,0x10,0x10,0x10,0x20,0x10,0x10,0x10,0x10,0x18,0x00,
/*--    |  --*/
0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x10,
/*--   }  --*/
0x00,0x60,0x20,0x20,0x20,0x10,0x20,0x20,0x20,0x20,0x60,0x00,
/*--  ~  --*/
0x40,0xA4,0x18,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,

};  





unsigned int code pic[]=
{/* 0X10,0X10,0X00,0X28,0X00,0XA0,0X01,0X1B, */
0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,
0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,
0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,
0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,
0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X83,0X69,0XCA,0XA2,0XD0,0XA2,0XB0,
0X61,0XA9,0X18,0X83,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X30,0XC4,0XB2,0XF1,0XF4,0X17,0XFC,0X59,0XFC,0X59,0XFC,0X59,
0XFC,0X59,0XEC,0X17,0XA2,0XD0,0X28,0XA4,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X61,0XA9,0XF4,0X18,0XFC,0X59,0XFC,0X38,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XFC,0X38,0XFC,0X79,0XEB,0XF7,0X49,0X47,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X69,0XCA,0XFC,0X59,0XFC,0X38,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XF4,0X18,0XF4,0X18,0XFC,0X38,0XFC,0X59,0X59,0X88,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X41,0X26,
0XFC,0X38,0XFC,0X38,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XFC,0X38,0XEB,0XF7,0X28,0XC4,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X20,0XCB,0X74,
0XFC,0X59,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XFC,0X59,0XC3,0X33,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X61,0XAA,0XFC,0X59,
0XF3,0XF7,0XF3,0XD7,0XF3,0XD7,0XF3,0XD7,0XF3,0XD7,0XF3,0XD7,0XF3,0XD7,0XF3,0XD7,
0XF3,0XD7,0XF3,0XD7,0XF3,0XD7,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XFC,0X59,0X51,0X47,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XCB,0X74,0XFC,0X79,
0XFD,0XFB,0XFE,0X1B,0XFE,0X1B,0XFE,0X1C,0XFE,0X3C,0XFE,0X3C,0XFE,0X3C,0XFE,0X3C,
0XFE,0X1B,0XFE,0X1B,0XFD,0XFB,0XFC,0X99,0XF3,0XF7,0XF4,0X18,0XFC,0X59,0XAA,0XF1,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0XA2,0X39,0XE7,0X29,0X65,0X10,0X82,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X39,0X05,0XFC,0X18,0XFC,0X38,
0XFF,0X5E,0XFF,0XFF,0XFF,0XFF,0XFE,0X5C,0XFD,0XBB,0XFD,0XBB,0XFD,0XBB,0XFD,0X9B,
0XFF,0X5E,0XFF,0XFF,0XFF,0XFF,0XFF,0X7E,0XF4,0X58,0XF4,0X18,0XFC,0X38,0XF4,0X17,
0X28,0XA4,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X82,0X8C,0X51,0X84,0X30,0X08,0X41,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X71,0XEB,0XFC,0X59,0XF3,0XD7,
0XFE,0X1C,0XFF,0XFF,0XFF,0XFF,0XFD,0X7A,0XF3,0XB7,0XF3,0XF7,0XF3,0XD7,0XF3,0XF7,
0XFF,0X5E,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0X3A,0XF3,0XF7,0XF4,0X18,0XFC,0X59,
0X61,0XA9,0X00,0X00,0X00,0X00,0X00,0X00,0X31,0XA6,0X84,0X10,0X84,0X30,0X00,0X20,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XA2,0XB0,0XFC,0X59,0XF3,0XF7,
0XFD,0X5A,0XFF,0XFF,0XFF,0XFF,0XFE,0X9D,0XF3,0XF7,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XFF,0X5E,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0X19,0XF3,0XF7,0XF4,0X18,0XFC,0X59,
0X8A,0X4D,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0XA2,0X94,0X92,0X84,0X10,0X08,0X61,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XC3,0X32,0XFC,0X59,0XF4,0X17,
0XF4,0X99,0XFF,0XDF,0XFF,0XFF,0XFF,0X9F,0XF4,0X58,0XF4,0X18,0XF4,0X18,0XF3,0XF7,
0XFD,0X9B,0XFF,0XFF,0XFF,0XFF,0XFE,0XFD,0XF4,0X38,0XF4,0X18,0XF4,0X18,0XFC,0X59,
0XB2,0XF1,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X7B,0XEF,0X7B,0XCF,0X08,0X61,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XCB,0X74,0XFC,0X38,0XF4,0X18,
0XF4,0X18,0XFF,0X3E,0XFF,0XFF,0XFF,0XFF,0XFC,0XD9,0XF3,0XF7,0XF4,0X18,0XF4,0X18,
0XF3,0XF7,0XFC,0XD9,0XFD,0X5A,0XF4,0X38,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XFC,0X59,
0XC3,0X53,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X6B,0X6D,0X94,0XB2,0X10,0X82,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XCB,0X74,0XFC,0X38,0XF4,0X18,
0XF3,0XF7,0XFE,0X5C,0XFF,0XFF,0XFF,0XFF,0XFD,0XDB,0XF3,0XF7,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XF3,0XF7,0XF3,0XF7,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XFC,0X59,
0XCB,0X53,0X00,0X00,0X00,0X00,0X00,0X00,0X4A,0X49,0XA5,0X34,0X6B,0X6D,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XCB,0X53,0XFC,0X39,0XF4,0X18,
0XF3,0XF7,0XFD,0X7A,0XFF,0XFF,0XFF,0XFF,0XFE,0X9D,0XF3,0XB7,0XF3,0XD7,0XF3,0XD7,
0XF3,0XD7,0XF3,0XD7,0XF3,0XD7,0XF3,0XD7,0XF3,0XF7,0XF4,0X18,0XF4,0X18,0XFC,0X59,
0XBB,0X32,0X00,0X00,0X00,0X00,0X00,0X00,0X31,0X86,0XAD,0X55,0X8C,0X71,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XBB,0X12,0XFC,0X59,0XF4,0X18,
0XF3,0XF7,0XFC,0XB9,0XFF,0XFF,0XFF,0XFF,0XFF,0XBF,0XFE,0X3C,0XFE,0X3C,0XFE,0X3C,
0XFE,0X3C,0XFE,0X3C,0XFE,0X1B,0XFD,0XFB,0XFD,0XDB,0XF4,0X78,0XF4,0X18,0XFC,0X59,
0XA2,0XD0,0X00,0X00,0X00,0X00,0X00,0X00,0X52,0XAA,0XB5,0XB6,0X7B,0XEF,0X00,0X20,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X92,0X6E,0XFC,0X59,0XF4,0X18,
0XF4,0X18,0XF4,0X18,0XFD,0XDB,0XFE,0X3C,0XFE,0X3C,0XFE,0X7C,0XFE,0X7C,0XFE,0X7C,
0XFE,0X7C,0XFE,0X5C,0XFF,0X7E,0XFF,0XFF,0XFF,0XFF,0XFF,0X3E,0XF4,0X38,0XFC,0X59,
0X7A,0X0C,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X41,0X08,0X41,0X10,0X82,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X59,0X89,0XFC,0X59,0XF4,0X18,
0XF4,0X18,0XF4,0X18,0XF3,0XF7,0XF3,0XD7,0XF3,0XD7,0XF3,0XF7,0XF3,0XF7,0XF3,0XF7,
0XF3,0XD7,0XF3,0XF7,0XFF,0X3E,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0X1A,0XFC,0X39,
0X49,0X47,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X83,0XEB,0XF7,0XFC,0X38,
0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XF4,0X38,0XFF,0X5E,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFD,0X3A,0XDB,0X75,
0X10,0X41,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XAA,0XF0,0XFC,0X59,
0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XF3,0XF7,0XFD,0XDB,0XFF,0XFF,0XFF,0XFF,0XFF,0X3E,0XFC,0X9A,0X8A,0X4D,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X30,0XE5,0XF4,0X18,
0XFC,0X38,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XF4,0X18,0XF4,0X18,0XFD,0X5A,0XFD,0XDB,0XFC,0X79,0XF3,0XF7,0X20,0XA4,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X9A,0X8F,
0XFC,0X79,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF3,0XF7,0XF3,0XD7,0XFC,0X59,0X82,0X4D,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X42,
0XCB,0X74,0XFC,0X59,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XFC,0X79,0XB3,0X12,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X20,0X83,0XDB,0XB5,0XFC,0X59,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,0XF4,0X18,
0XF4,0X18,0XF4,0X18,0XF4,0X38,0XFC,0X59,0XCB,0X74,0X18,0X62,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X18,0X82,0XAA,0XD0,0XFC,0X59,0XFC,0X59,0XFC,0X38,0XFC,0X38,0XFC,0X38,
0XFC,0X38,0XFC,0X59,0XFC,0X59,0X9A,0XAF,0X10,0X41,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X51,0X68,0XB2,0XF1,0XDB,0XB5,0XEB,0XF7,0XEB,0XF7,
0XDB,0XB5,0XAA,0XF1,0X49,0X27,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X41,0X20,0XA3,0X20,0X83,
0X08,0X21,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X21,0X08,0X84,0X08,0XA5,
0X00,0X42,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XC6,0X2A,0X93,0X33,0X7A,0X3B,0X9C,0X33,0X9C,
0X33,0X5A,0X22,0XD6,0X11,0X2A,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X21,0X2A,0X71,0X4C,0X3D,0X44,0X5E,0X44,0X1D,0X3B,0XFD,0X3B,0XDD,
0X3B,0XDD,0X3B,0XDE,0X33,0XDE,0X22,0XB6,0X08,0XA5,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X21,0X3B,0X55,0X54,0XBF,0X4C,0X5D,0X4C,0X3D,0X44,0X1D,0X44,0X1D,0X43,0XFD,
0X3B,0XDD,0X3B,0XDD,0X3B,0XBD,0X3B,0XDE,0X33,0X7B,0X08,0XC6,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X42,0X28,0X5A,0XCB,0X10,0XA2,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X3B,0X34,0X5C,0XDF,0X54,0X7D,0X54,0X7D,0X4C,0X5D,0X4C,0X3D,0X4C,0X3D,0X44,0X1D,
0X44,0X1D,0X43,0XFD,0X3B,0XDD,0X3B,0XDD,0X3B,0XDE,0X33,0X5A,0X00,0X84,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X84,0X10,0X84,0X30,0X18,0XE3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X2A,0X0D,
0X65,0X1F,0X5C,0XBD,0X5C,0XBD,0X5C,0X9D,0X54,0X7D,0X54,0X7D,0X4C,0X5D,0X4C,0X3D,
0X4C,0X3D,0X44,0X1D,0X44,0X1D,0X43,0XFD,0X3B,0XDD,0X3C,0X1E,0X2A,0XD5,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X5A,0XCB,0X8C,0X71,0X21,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X62,0X64,0X9B,
0X6D,0X1E,0X64,0XDD,0X64,0XDD,0X5C,0XBD,0X5C,0X9D,0X54,0X9D,0X54,0X7D,0X54,0X5D,
0X4C,0X5D,0X4C,0X3D,0X4C,0X3D,0X44,0X1D,0X44,0X1D,0X43,0XFD,0X44,0X1E,0X11,0X49,
0X00,0X00,0X00,0X00,0X00,0X00,0X10,0XA2,0X08,0X61,0X10,0XA2,0X00,0X00,0X00,0X00,
0X00,0X00,0X6B,0X6D,0X9C,0XD3,0X31,0X86,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X32,0X6E,0X75,0X7F,
0X6D,0X1D,0X6D,0X1D,0X64,0XFD,0X64,0XDD,0X64,0XDD,0X64,0XDD,0X64,0XBD,0X5C,0XBD,
0X54,0X7D,0X4C,0X5D,0X4C,0X5D,0X4C,0X3D,0X4C,0X3D,0X44,0X1D,0X44,0X3E,0X32,0XF5,
0X00,0X00,0X00,0X00,0X00,0X00,0X52,0XAA,0X7B,0XCF,0X5A,0XCB,0X00,0X00,0X00,0X00,
0X10,0XA2,0X6B,0X4D,0X94,0XB2,0X18,0XE3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X64,0X99,0X7D,0X7F,
0X75,0X3E,0X6D,0X3D,0X6D,0X1D,0X64,0XDD,0X95,0XDE,0XF7,0XBF,0XEF,0XBF,0XEF,0XBF,
0XDF,0X3F,0X8D,0X9E,0X54,0X5D,0X4C,0X5D,0X54,0X5D,0X4C,0X3D,0X44,0X1D,0X4C,0X3D,
0X11,0X07,0X00,0X00,0X08,0X41,0X42,0X28,0X9C,0XD3,0X31,0X86,0X00,0X00,0X00,0X00,
0X08,0X61,0X8C,0X71,0X7B,0XCF,0X29,0X65,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X19,0X26,0X7D,0X9E,0X7D,0X7E,
0X75,0X5E,0X6D,0X3D,0X6D,0X1D,0X64,0XFD,0X7D,0X7E,0XC6,0XDF,0XC6,0XDF,0XCE,0XFF,
0XEF,0XBF,0XFF,0XFF,0XC6,0XBE,0X5C,0X9D,0X54,0X5D,0X75,0X1D,0X75,0X3D,0X4C,0X7F,
0X22,0X0E,0X00,0X00,0X00,0X00,0X6B,0X6D,0X73,0X8E,0X4A,0X49,0X00,0X00,0X00,0X00,
0X00,0X00,0X73,0XAE,0X9C,0XD3,0X21,0X24,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X32,0X4B,0X8D,0XFF,0X7D,0X9E,
0X8D,0XDE,0XB6,0X9E,0XBE,0XBE,0XBE,0XBE,0XB6,0X7E,0XAE,0X5E,0XAE,0X5E,0XA6,0X3E,
0X85,0X9E,0XBE,0X9F,0XFF,0XFF,0XB6,0X7E,0X4C,0X5D,0XD7,0X1F,0XDF,0X3F,0X4C,0X7E,
0X3B,0X15,0X00,0X00,0X00,0X00,0X73,0X8E,0X7B,0XCF,0X29,0X65,0X00,0X00,0X00,0X00,
0X00,0X20,0X63,0X0C,0XA5,0X14,0X39,0XC7,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X4B,0X30,0X8E,0X1F,0XA6,0X5E,
0XF7,0XDF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0X95,0XDE,0XCE,0XFF,0XFF,0XFF,0X64,0XFD,0XCE,0XFF,0XDF,0X5F,0X54,0X9E,
0X43,0XD8,0X00,0X00,0X00,0X00,0X52,0X8A,0XAD,0X55,0X52,0X8A,0X00,0X00,0X00,0X00,
0X42,0X08,0X73,0XAE,0X94,0X92,0X21,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X5B,0XD3,0X96,0X3F,0XDF,0X7F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XE7,0X7F,0X95,0XFE,0XFF,0XFF,0XA6,0X3E,0XDF,0X3F,0XDF,0X5F,0X5C,0XBE,
0X4C,0X1A,0X00,0X21,0X00,0X00,0X39,0XE7,0X9C,0XF3,0X29,0X45,0X00,0X00,0X00,0X00,
0X00,0X00,0X5A,0XEB,0X84,0X10,0X29,0X65,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X64,0X34,0X9E,0X9F,0XF7,0XDF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XF7,0XDF,0X8D,0XDE,0XF7,0XDF,0XFF,0XFF,0XFF,0XFF,0XD7,0X3F,0X64,0XDE,
0X54,0X5B,0X00,0X41,0X00,0X00,0X63,0X2C,0X9C,0XD3,0X39,0XC7,0X00,0X00,0X00,0X00,
0X00,0X00,0X63,0X2C,0X94,0XB2,0X29,0X65,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X64,0X34,0X9E,0X9F,0XE7,0X9F,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XEF,0X9F,0X9E,0X1E,0XFF,0XFF,0XC6,0XDF,0XE7,0X9F,0XDF,0X5F,0X65,0X1E,
0X5C,0X7A,0X00,0X41,0X00,0X00,0X42,0X28,0XA5,0X34,0X42,0X28,0X00,0X00,0X00,0X00,
0X00,0X00,0X7B,0XEF,0X7B,0XEF,0X18,0XC3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X5B,0XD1,0XA6,0XBF,0XBE,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XFF,0XFF,0XB6,0X7E,0XCE,0XFF,0XFF,0XFF,0X7D,0X9E,0XD7,0X1F,0XE7,0X7F,0X6D,0X3E,
0X5C,0X79,0X00,0X21,0X00,0X00,0X52,0XAA,0X84,0X30,0X5A,0XCB,0X00,0X00,0X00,0X00,
0X00,0X00,0X52,0XAA,0X94,0XB2,0X29,0X45,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X4A,0XED,0XAE,0XFF,0X9E,0X7E,
0XB6,0XDF,0XDF,0X7F,0XE7,0X9F,0XE7,0X9F,0XE7,0X9F,0XDF,0X7F,0XE7,0X7F,0XDF,0X5F,
0XAE,0X9E,0XB6,0X9F,0XFF,0XFF,0XCF,0X1F,0X75,0X5E,0XDF,0X5F,0XE7,0X7F,0X75,0X7F,
0X5C,0X17,0X00,0X00,0X00,0X00,0X39,0XE7,0X9C,0XD3,0X29,0X65,0X00,0X00,0X00,0X00,
0X00,0X00,0X63,0X0C,0X94,0X92,0X31,0XA6,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X31,0XE8,0XB6,0XFF,0XA6,0XBF,
0X9E,0X9E,0X9E,0X7E,0X9E,0X5E,0X96,0X5E,0X9E,0X7E,0XBE,0XDF,0XBE,0XDF,0XBE,0XBF,
0XDF,0X7F,0XFF,0XFF,0XE7,0X9F,0X8D,0XDE,0X7D,0X9E,0XAE,0X7E,0XB6,0X9E,0X7D,0XBF,
0X43,0X31,0X00,0X00,0X18,0XC3,0X9C,0XF3,0X7B,0XEF,0X31,0X86,0X00,0X00,0X00,0X00,
0X00,0X00,0X6B,0X6D,0X63,0X2C,0X10,0XA2,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X82,0XA6,0X5C,0XB6,0XFF,
0XAE,0XBF,0XA6,0XBE,0XA6,0X9E,0X9E,0X7E,0XBE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XF7,0XDF,0XCF,0X1F,0X95,0XFE,0X85,0XDE,0X8D,0XDE,0X7D,0XBE,0X7D,0X9E,0X85,0XFF,
0X29,0XEA,0X00,0X00,0X29,0X65,0XA5,0X14,0X52,0X8A,0X08,0X41,0X00,0X00,0X00,0X00,
0X4A,0X49,0X5A,0XCB,0X52,0X8A,0X10,0XA2,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X74,0X94,0XBF,0X5F,
0XAE,0XFF,0XAE,0XDF,0XAE,0XBF,0XA6,0XBF,0XA6,0XBF,0XB6,0XDF,0XB6,0XDF,0XAE,0XBF,
0X9E,0X5E,0X8E,0X1E,0X96,0X1E,0X96,0X1E,0X8D,0XFE,0X8D,0XFE,0X8D,0XFF,0X75,0X1A,
0X08,0X62,0X00,0X00,0X39,0XC7,0X94,0XB2,0X94,0X92,0X29,0X45,0X00,0X00,0X00,0X00,
0X6B,0X6D,0X7B,0XCF,0X52,0XAA,0X10,0XA2,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X21,0X66,0XBF,0X3F,
0XB7,0X1F,0XB6,0XFF,0XB6,0XFF,0XAE,0XDF,0XAE,0XBF,0XA6,0X9E,0X9E,0X9E,0X9E,0X7E,
0X9E,0X7E,0X9E,0X5E,0X9E,0X5E,0X96,0X3E,0X96,0X3E,0X96,0X1E,0X96,0X7F,0X43,0X0F,
0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X82,0X10,0XA2,0X08,0X41,0X00,0X00,0X00,0X00,
0X10,0X82,0X00,0X20,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X7C,0XB4,
0XC7,0X9F,0XB7,0X1F,0XB7,0X1F,0XB6,0XFF,0XAE,0XFF,0XAE,0XDF,0XAE,0XBF,0XA6,0XBF,
0XA6,0X9E,0XA6,0X9E,0X9E,0X7E,0X9E,0X5E,0X9E,0X5E,0X9E,0X7F,0X85,0X9B,0X08,0X82,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0XE3,
0XB6,0XBC,0XC7,0X9F,0XBF,0X3F,0XB7,0X1F,0XB7,0X1F,0XB6,0XFF,0XAE,0XFF,0XAE,0XDF,
0XAE,0XBF,0XA6,0XBF,0XA6,0X9E,0XA6,0X7E,0XA6,0X9F,0XA6,0X9F,0X3A,0X4B,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X29,0XC7,0XBF,0X3D,0XCF,0XBF,0XBF,0X5F,0XBF,0X3F,0XB7,0X1F,0XB7,0X1F,0XB6,0XFF,
0XAE,0XFF,0XAE,0XDF,0XAE,0XDF,0XAE,0XDF,0XAE,0XFF,0X53,0X2F,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X32,0X08,0XB6,0XDC,0XCF,0XDF,0XC7,0X7F,0XBF,0X5F,0XBF,0X3F,0XBF,0X3F,
0XB7,0X1F,0XB6,0XFF,0XB7,0X3F,0XAE,0XFF,0X53,0X4F,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X10,0XC3,0X74,0X72,0XBF,0X1D,0XCF,0XDF,0XCF,0XBF,0XC7,0X9F,
0XC7,0X9F,0XBF,0X3F,0X85,0X37,0X29,0XA7,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X19,0X04,0X4A,0XCC,0X6C,0X11,0X6C,0X52,
0X53,0X4E,0X29,0XA7,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X20,0X18,0X80,0X18,0XA0,
0X08,0X20,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X28,0XE0,0X7A,0XC0,0XCC,0X60,0XED,0X20,0XED,0X20,
0XCC,0X60,0X82,0XE0,0X28,0XE0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X08,0X40,0X83,0X00,0XF5,0X80,0XFE,0X00,0XFD,0XC0,0XFD,0XA0,0XFD,0XA0,
0XFD,0XA0,0XFD,0XC0,0XFD,0X60,0X93,0X20,0X08,0X40,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X08,0X40,0XB4,0X20,0XFE,0X20,0XFD,0XC0,0XFD,0XA0,0XFD,0XA0,0XFD,0X80,0XFD,0X80,
0XFD,0X80,0XFD,0X60,0XFD,0X80,0XFD,0XC0,0XBC,0X00,0X10,0X60,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0XAC,0X00,0XFE,0X40,0XFD,0XC0,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0X80,0XFD,0X80,
0XFD,0X80,0XFD,0X60,0XFD,0X60,0XFD,0X60,0XFD,0XC0,0XB3,0XE0,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X72,0XC0,
0XFE,0X40,0XFD,0XE0,0XFD,0XC0,0XFD,0XE2,0XFE,0X04,0XFD,0XE4,0XFD,0XE4,0XFD,0XE4,
0XFD,0XE4,0XFD,0XE4,0XFD,0XC4,0XFD,0XC3,0XFD,0X60,0XFD,0XC0,0X82,0XC0,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X08,0X41,0X10,0XA2,0X00,0X20,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0XA0,0XED,0XA0,
0XFE,0X20,0XFD,0XE0,0XFE,0X24,0XFF,0X99,0XFF,0X99,0XFF,0X98,0XFF,0X98,0XFF,0X78,
0XFF,0X78,0XFF,0X78,0XFF,0X78,0XFF,0XBB,0XFE,0XF1,0XFD,0X80,0XF5,0X60,0X28,0XE0,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X73,0XAE,0X8C,0X51,0X21,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X8B,0X60,0XFE,0X60,
0XFE,0X00,0XFD,0XC0,0XFF,0X32,0XFF,0X12,0XFD,0XC0,0XFD,0XE1,0XFD,0XE1,0XFD,0XC1,
0XFD,0XC1,0XFD,0XA1,0XFD,0XA0,0XFD,0XE4,0XFF,0X9A,0XFD,0XA3,0XFD,0XC0,0X93,0X20,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X73,0XAE,0X94,0XB2,0X18,0XC3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X40,0XDD,0X80,0XFE,0X40,
0XFE,0X00,0XFD,0XE0,0XFF,0X33,0XFE,0XAD,0XFE,0X02,0XFD,0XE1,0XFD,0XC0,0XFD,0XC0,
0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFD,0XA0,0XFF,0X78,0XFD,0XC3,0XFD,0XA0,0XE5,0X00,
0X10,0X60,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X6B,0X4D,0X9C,0XF3,0X29,0X65,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X41,0XC0,0XFE,0X40,0XFE,0X20,
0XFE,0X00,0XFD,0XE0,0XFF,0X53,0XFE,0XCC,0XFE,0XAB,0XFE,0X46,0XFD,0XC0,0XFD,0XC0,
0XFD,0XC0,0XFD,0XA0,0XFD,0XA0,0XFD,0XC1,0XFF,0X78,0XFD,0XC3,0XFD,0X80,0XFD,0XE0,
0X59,0XE0,0X00,0X00,0X00,0X00,0X31,0X86,0X73,0X8E,0X29,0X45,0X00,0X00,0X00,0X00,
0X00,0X00,0X5A,0XEB,0X8C,0X51,0X21,0X24,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X72,0XE0,0XFE,0X80,0XFE,0X20,
0XFE,0X42,0XFF,0X11,0XFF,0XBB,0XFE,0X89,0XFD,0XC0,0XFE,0X02,0XFF,0X11,0XFF,0X77,
0XFF,0X56,0XFE,0X69,0XFD,0XA0,0XFD,0XC1,0XFF,0X78,0XFD,0XE3,0XFD,0X80,0XFD,0XE0,
0X8B,0X00,0X00,0X00,0X00,0X00,0X5A,0XCB,0X8C,0X51,0X5A,0XEB,0X00,0X00,0X00,0X00,
0X18,0XC3,0X6B,0X4D,0X7B,0XEF,0X21,0X24,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XA4,0X20,0XFE,0X80,0XFE,0X20,
0XFF,0X10,0XFF,0X99,0XFE,0X43,0XFE,0X00,0XFE,0X22,0XFF,0XBB,0XFF,0X76,0XFE,0XAA,
0XFE,0XCE,0XFF,0XDD,0XFE,0XAC,0XFD,0XC0,0XFF,0X78,0XFD,0XE3,0XFD,0XA0,0XFD,0XE0,
0XBC,0X20,0X00,0X00,0X00,0X00,0X63,0X0C,0X8C,0X51,0X42,0X28,0X00,0X00,0X00,0X00,
0X08,0X41,0X8C,0X71,0X7B,0XEF,0X21,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XBC,0XC0,0XFE,0X80,0XFE,0X20,
0XFF,0X31,0XFF,0X0F,0XFE,0X00,0XFE,0X00,0XFF,0X0F,0XFF,0X77,0XFD,0XE0,0XFD,0XC0,
0XFD,0XA0,0XFE,0X47,0XFF,0XBB,0XFE,0X04,0XFF,0X77,0XFE,0X03,0XFD,0XA0,0XFD,0XE0,
0XCC,0XA0,0X00,0X00,0X00,0X00,0X6B,0X4D,0X94,0XB2,0X29,0X65,0X00,0X00,0X00,0X00,
0X00,0X00,0X6B,0X6D,0XA5,0X14,0X29,0X65,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XCD,0X20,0XFE,0X80,0XFE,0X20,
0XFF,0X30,0XFF,0X10,0XFE,0X00,0XFE,0X00,0XFF,0X76,0XFE,0XAB,0XFD,0XE0,0XFE,0X00,
0XFD,0XE0,0XFD,0XE0,0XFF,0X9A,0XFE,0X68,0XFF,0X77,0XFE,0X03,0XFD,0XA0,0XFD,0XE0,
0XD4,0XC0,0X00,0X20,0X00,0X00,0X52,0XAA,0X84,0X10,0X5A,0XEB,0X00,0X00,0X00,0X00,
0X18,0XC3,0X63,0X2C,0XAD,0X55,0X31,0X86,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XCD,0X20,0XFE,0XA0,0XFE,0X40,
0XFF,0X30,0XFF,0X10,0XFE,0X20,0XFE,0X20,0XFF,0X32,0XFF,0X32,0XFE,0X00,0XFE,0X00,
0XFD,0XE0,0XFE,0X24,0XFF,0XBB,0XFE,0X46,0XFF,0X77,0XFE,0X03,0XFD,0XC0,0XFD,0XE0,
0XD4,0XC0,0X00,0X20,0X00,0X00,0X31,0XA6,0XA5,0X14,0X31,0XA6,0X00,0X00,0X00,0X00,
0X31,0XA6,0X73,0XAE,0X94,0X92,0X21,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XBC,0XC0,0XFE,0XA0,0XFE,0X40,
0XFF,0X30,0XFF,0X74,0XFE,0X41,0XFE,0X20,0XFE,0X86,0XFF,0XDD,0XFE,0XCB,0XFE,0X21,
0XFE,0X43,0XFF,0X76,0XFF,0X33,0XFD,0XE0,0XFF,0X78,0XFE,0X23,0XFD,0XC0,0XFE,0X00,
0XCC,0XA0,0X00,0X00,0X08,0X61,0X8C,0X71,0X7B,0XCF,0X29,0X65,0X00,0X00,0X00,0X00,
0X00,0X00,0X6B,0X4D,0X8C,0X71,0X31,0XA6,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X93,0XE0,0XFE,0XC0,0XFE,0X60,
0XFE,0XA5,0XFF,0X97,0XFF,0XBA,0XFE,0XA5,0XFE,0X20,0XFE,0XA8,0XFF,0X99,0XFF,0XBB,
0XFF,0XBB,0XFF,0X53,0XFE,0X00,0XFE,0X01,0XFF,0X98,0XFE,0X23,0XFD,0XE0,0XFE,0X20,
0XAB,0XE0,0X00,0X00,0X29,0X45,0XA5,0X14,0X52,0XAA,0X10,0X82,0X00,0X00,0X00,0X00,
0X00,0X00,0X63,0X2C,0X7B,0XCF,0X18,0XE3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X62,0XA0,0XFE,0XE0,0XFE,0X80,
0XFE,0X60,0XFE,0X40,0XFF,0X75,0XFF,0X0E,0XFE,0X20,0XFE,0X20,0XFE,0X40,0XFE,0X85,
0XFE,0X43,0XFE,0X00,0XFE,0X00,0XFE,0X21,0XFF,0X98,0XFE,0X23,0XFD,0XE0,0XFE,0X40,
0X7A,0XE0,0X00,0X00,0X39,0XE7,0X9C,0XF3,0X73,0XAE,0X10,0X82,0X00,0X00,0X00,0X00,
0X00,0X00,0X73,0X8E,0X73,0X8E,0X18,0XC3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X31,0X60,0XFE,0X80,0XFE,0X80,
0XFE,0X60,0XFE,0XE7,0XFF,0XDC,0XFF,0X0C,0XFE,0X40,0XFE,0X40,0XFE,0X40,0XFE,0X20,
0XFE,0X20,0XFE,0X20,0XFE,0X20,0XFE,0X21,0XFF,0X98,0XFE,0X43,0XFE,0X00,0XFE,0X20,
0X41,0X80,0X00,0X00,0X08,0X61,0X31,0XA6,0X42,0X08,0X18,0XE3,0X00,0X00,0X00,0X00,
0X00,0X00,0X6B,0X4D,0XAD,0X75,0X31,0X86,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0XCD,0X60,0XFE,0XC0,
0XFE,0X80,0XFE,0XE8,0XFF,0XDC,0XFF,0X0D,0XFE,0X40,0XFE,0X40,0XFE,0X40,0XFE,0X40,
0XFE,0X20,0XFE,0X20,0XFE,0X00,0XFE,0X21,0XFF,0X98,0XFE,0X43,0XFE,0X40,0XCC,0XE0,
0X00,0X20,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X5A,0XEB,0X7B,0XEF,0X29,0X45,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X62,0XA0,0XFE,0XE0,
0XFE,0XA0,0XFE,0X60,0XFE,0XE9,0XFF,0XDB,0XFF,0X52,0XFF,0X51,0XFF,0X51,0XFF,0X51,
0XFF,0X31,0XFF,0X31,0XFF,0X31,0XFF,0X76,0XFF,0X98,0XFE,0X20,0XFE,0X60,0X72,0XC0,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X6B,0X4D,0X7B,0XCF,0X18,0XC3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X20,0XCD,0X80,
0XFE,0XE0,0XFE,0XA0,0XFE,0X80,0XFE,0XE8,0XFF,0X4F,0XFF,0X2F,0XFF,0X2F,0XFF,0X2F,
0XFF,0X2F,0XFF,0X2F,0XFF,0X2F,0XFF,0X0E,0XFE,0X42,0XFE,0X40,0XDD,0X60,0X10,0X60,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X63,0X2C,0X6B,0X6D,0X52,0X8A,0X10,0XA2,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X4A,0X00,
0XFE,0XC0,0XFE,0XC0,0XFE,0XA0,0XFE,0X80,0XFE,0X60,0XFE,0X60,0XFE,0X60,0XFE,0X40,
0XFE,0X40,0XFE,0X40,0XFE,0X20,0XFE,0X20,0XFE,0X40,0XFE,0X60,0X5A,0X20,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X5A,0XEB,0X5A,0XCB,0X39,0XC7,0X08,0X61,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X72,0XE0,0XFE,0XE0,0XFE,0XC0,0XFE,0XA0,0XFE,0XA0,0XFE,0X80,0XFE,0X80,0XFE,0X80,
0XFE,0X60,0XFE,0X60,0XFE,0X60,0XFE,0X60,0XFE,0XA0,0X7B,0X20,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X7B,0X40,0XF6,0XA0,0XFE,0XE0,0XFE,0XA0,0XFE,0XA0,0XFE,0XA0,0XFE,0X80,
0XFE,0X80,0XFE,0X80,0XFE,0XA0,0XFE,0X80,0X83,0X60,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X39,0XA0,0XCD,0X60,0XFE,0XC0,0XFE,0XE0,0XFE,0XE0,0XFE,0XC0,
0XFE,0XE0,0XFE,0XC0,0XD5,0X80,0X49,0XE0,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X49,0XE0,0X8B,0XA0,0XAC,0X60,0XAC,0X60,
0X8B,0XC0,0X52,0X20,0X08,0X20,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X00,0X20,0X00,0X20,
0X00,0X20,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X60,0X1A,0X21,0X3C,0X23,0X4D,0X03,0X4D,0X03,
0X3C,0X23,0X22,0X41,0X00,0X60,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X1A,0X01,0X5E,0X25,0X77,0XE6,0X77,0XE6,0X77,0XE6,0X77,0XE6,
0X77,0XE6,0X77,0XE6,0X5E,0X25,0X22,0X21,0X00,0X20,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X3B,0XE3,0X77,0XC7,0X77,0XC7,0X6F,0X87,0X6F,0X87,0X6F,0X87,0X6F,0X87,
0X6F,0X87,0X6F,0X87,0X77,0XE7,0X77,0XC7,0X3B,0XC3,0X00,0X20,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X33,0X83,0X7F,0XE8,0X77,0XA7,0X77,0X87,0X77,0X87,0X77,0X87,0X77,0X87,0X77,0X87,
0X77,0X87,0X77,0X87,0X77,0X87,0X77,0XA7,0X7F,0XE8,0X3B,0XA3,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X22,0X82,
0X7F,0XE8,0X77,0XA8,0X77,0X88,0X77,0X88,0X77,0X88,0X77,0X88,0X77,0X88,0X77,0X88,
0X77,0X88,0X77,0X88,0X77,0X88,0X77,0X88,0X77,0XA8,0X77,0XE8,0X2A,0X82,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X60,0X66,0X67,
0X7F,0XC9,0X77,0X88,0X77,0X88,0X77,0X88,0X77,0X88,0X77,0X88,0X7F,0X8A,0X8F,0X8C,
0X77,0X88,0X77,0X89,0X77,0X88,0X77,0X88,0X77,0X88,0X7F,0XE9,0X6E,0XA8,0X08,0X80,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X18,0XE3,0X00,0X20,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X33,0X44,0X7F,0XEA,
0X77,0X89,0X8F,0XAD,0XBF,0XD4,0XB7,0XB3,0XB7,0XB3,0XAF,0XB2,0X97,0XAE,0XB7,0XD4,
0X77,0X88,0X7F,0X8A,0XAF,0XB2,0XBF,0XD4,0X9F,0XAF,0X77,0X89,0X87,0XEA,0X33,0X64,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X84,0X10,0XA5,0X14,0X31,0X86,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X6E,0X69,0X7F,0XCA,
0X8F,0XAD,0XE7,0XFB,0XAF,0XD2,0X97,0XAE,0X97,0XAE,0X8F,0XAD,0X97,0XAE,0XB7,0XD4,
0X77,0X89,0X7F,0X8A,0X97,0XAE,0XA7,0XB0,0XE7,0XFB,0XA7,0XB0,0X7F,0XEA,0X66,0X28,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0XA2,0X94,0X92,0X42,0X28,0X39,0XC7,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X19,0XC2,0X7F,0XAB,0X77,0XAA,
0XAF,0XB2,0XB7,0XD3,0X6F,0X88,0X77,0X8A,0X77,0X8A,0X7F,0X8A,0X9F,0XAF,0XBF,0XD5,
0X87,0XAB,0X87,0XAC,0X77,0X8A,0X6F,0X88,0X9F,0XAF,0XBF,0XD5,0X77,0XAA,0X87,0XCB,
0X22,0X03,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X41,0X8C,0X71,0X7B,0XEF,0X00,0X20,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X3B,0X65,0X87,0XEC,0X7F,0X8A,
0XAF,0XD2,0XA7,0XB1,0X7F,0XAB,0X7F,0XAB,0X9F,0XB0,0XF7,0XFE,0XCF,0XD8,0XEF,0XFD,
0XF7,0XFD,0XF7,0XFE,0XC7,0XD6,0X7F,0XAB,0X97,0XAF,0XBF,0XD5,0X7F,0X8B,0X87,0XEC,
0X3B,0XA5,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0X82,0XA5,0X14,0X9C,0XF3,0X08,0X61,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X54,0XE8,0X8F,0XED,0X7F,0XAC,
0X9F,0XB1,0X9F,0XB0,0X7F,0XAC,0X7F,0XAB,0XCF,0XD8,0XFF,0XFF,0XD7,0XD9,0XF7,0XFE,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X9F,0XB0,0X8F,0XAE,0XAF,0XD2,0X7F,0XAC,0X8F,0XED,
0X55,0X08,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X41,0X6B,0X6D,0X84,0X30,0X08,0X41,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X65,0XEA,0X8F,0XED,0X87,0XAD,
0X87,0XAC,0X87,0XAC,0X87,0XAD,0X7F,0XAC,0XD7,0XF9,0XFF,0XFF,0XD7,0XF9,0XF7,0XFE,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XA7,0XB2,0X7F,0XAC,0X87,0XAC,0X87,0XAD,0X8F,0XED,
0X6E,0X0A,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0XC3,0X9C,0XD3,0X42,0X08,0X00,0X20,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X6E,0X0B,0X8F,0XEE,0X87,0XAE,
0X87,0XAE,0X87,0XAE,0X87,0XAE,0X87,0XAD,0XD7,0XF9,0XFF,0XFF,0XD7,0XF9,0XF7,0XFE,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XA7,0XD2,0X87,0XAD,0X87,0XAD,0X87,0XAE,0X8F,0XEE,
0X6E,0X6B,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X8C,0X51,0X7B,0XEF,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X6E,0X0B,0X8F,0XEF,0X8F,0XAE,
0X8F,0XAE,0X8F,0XAE,0X8F,0XAE,0X87,0XAD,0XD7,0XF9,0XFF,0XFF,0XD7,0XF9,0XF7,0XFE,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XA7,0XD2,0X87,0XAD,0X87,0XAE,0X8F,0XAE,0X8F,0XEF,
0X76,0X6C,0X00,0X20,0X00,0X00,0X00,0X00,0X18,0XC3,0X84,0X30,0X73,0XAE,0X10,0X82,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X6D,0XEB,0X97,0XF0,0X8F,0XAF,
0X9F,0XD1,0X97,0XD0,0X8F,0XAF,0X87,0XAE,0XD7,0XFA,0XFF,0XFF,0XD7,0XFA,0XF7,0XFE,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XA7,0XD3,0X8F,0XAF,0X9F,0XD1,0X8F,0XAF,0X97,0XF0,
0X6E,0X2C,0X00,0X00,0X00,0X00,0X00,0X00,0X18,0XC3,0X84,0X10,0X7B,0XEF,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X65,0X2A,0X97,0XF0,0X8F,0XAF,
0XB7,0XD5,0XB7,0XD4,0X8F,0XAF,0X87,0XAF,0XC7,0XD7,0XFF,0XFF,0XD7,0XFA,0XF7,0XFE,
0XFF,0XFF,0XFF,0XFF,0XF7,0XFE,0X9F,0XD1,0XA7,0XD2,0XC7,0XD7,0X8F,0XAF,0X97,0XF0,
0X65,0X6B,0X00,0X00,0X00,0X00,0X00,0X00,0X31,0X86,0X7B,0XCF,0X63,0X2C,0X08,0X61,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X43,0XC8,0X9F,0XF1,0X8F,0XCF,
0XB7,0XD5,0XB7,0XD5,0X8F,0XD0,0X8F,0XD0,0X97,0XD1,0XCF,0XF8,0XC7,0XD7,0XDF,0XFB,
0XCF,0XF8,0XCF,0XF8,0XA7,0XD3,0X8F,0XCF,0XA7,0XD3,0XC7,0XF7,0X8F,0XD0,0X9F,0XF1,
0X4B,0XE8,0X00,0X00,0X00,0X00,0X00,0X00,0X29,0X65,0X8C,0X71,0X4A,0X69,0X08,0X61,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X2A,0X45,0X97,0XF2,0X8F,0XD0,
0XBF,0XD6,0XCF,0XF8,0X8F,0XD0,0X8F,0XD1,0X8F,0XD0,0X87,0XCF,0XA7,0XD3,0XC7,0XF7,
0X87,0XCF,0X8F,0XD0,0X8F,0XD0,0X8F,0XD0,0XB7,0XD5,0XC7,0XF8,0X8F,0XD0,0X9F,0XF2,
0X2A,0X85,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0XA2,0X73,0XAE,0X6B,0X6D,0X10,0X82,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X61,0X86,0XF0,0X97,0XF2,
0X9F,0XD3,0XE7,0XFC,0XCF,0XF9,0XB7,0XD5,0XB7,0XD5,0XAF,0XD5,0XAF,0XD5,0XC7,0XF8,
0X97,0XD1,0X97,0XD2,0XAF,0XD5,0XC7,0XF7,0XEF,0XFD,0XAF,0XD5,0X97,0XF2,0X86,0XD0,
0X08,0X61,0X00,0X00,0X00,0X00,0X00,0X00,0X29,0X65,0X9C,0XF3,0X8C,0X51,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X54,0X6A,0XA7,0XF3,
0X97,0XD2,0XA7,0XD4,0XC7,0XF8,0XC7,0XF7,0XC7,0XF8,0XBF,0XF7,0XAF,0XF5,0XC7,0XF8,
0X97,0XD2,0X9F,0XD3,0XBF,0XF7,0XC7,0XF8,0XAF,0XF5,0X97,0XD2,0XA7,0XF4,0X54,0X2A,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X4A,0X69,0X8C,0X71,0X6B,0X4D,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X10,0XE2,0X97,0X52,
0X9F,0XF4,0X97,0XD3,0X97,0XD2,0X97,0XD2,0X97,0XD2,0X97,0XD2,0X9F,0XD3,0X9F,0XD4,
0X9F,0XD3,0X9F,0XD3,0X97,0XD2,0X97,0XD2,0X97,0XD3,0X9F,0XF4,0X97,0X72,0X11,0X02,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X7B,0XCF,0X39,0XE7,0X7B,0XEF,0X18,0XC3,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X4B,0XA9,
0XA7,0XD5,0X9F,0XF4,0X9F,0XF4,0X9F,0XF4,0X9F,0XF4,0X9F,0XF4,0X9F,0XD4,0X9F,0XD4,
0X9F,0XF4,0X9F,0XF4,0X9F,0XF4,0X9F,0XF4,0X9F,0XF4,0XA7,0XF5,0X4B,0XC9,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X29,0X65,0X52,0X8A,0X42,0X08,0X00,0X20,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X75,0X8E,0XA7,0XF5,0XA7,0XF4,0X9F,0XF4,0X9F,0XF4,0X9F,0XF4,0X9F,0XF4,0X9F,0XF4,
0X9F,0XF4,0X9F,0XF4,0X9F,0XF4,0XA7,0XF4,0XAF,0XF6,0X6D,0X6E,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X40,0X75,0XAF,0XAF,0XD6,0XA7,0XF6,0XA7,0XF5,0XA7,0XF5,0XA7,0XF5,0XA7,0XF5,
0XA7,0XF5,0XA7,0XF5,0XA7,0XF6,0XAF,0XD6,0X75,0XAF,0X08,0X81,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X40,0X5C,0X6C,0X9F,0X95,0XAF,0XD7,0XAF,0XF7,0XA7,0XF6,0XA7,0XF6,
0XA7,0XF7,0XAF,0XD7,0XA7,0X95,0X5C,0X8C,0X00,0X20,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X19,0X43,0X54,0X2C,0X8E,0X92,0X9F,0X55,0X9F,0X55,
0X8E,0X92,0X5C,0X4C,0X19,0X43,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X08,0XA2,0X08,0XA2,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X00,0X20,0X00,0X21,
0X00,0X20,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X41,0X11,0XA9,0X23,0X10,0X33,0XD4,0X33,0XF5,
0X2B,0X51,0X1A,0X2B,0X00,0X82,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X11,0X67,0X3C,0X57,0X4D,0XBE,0X4D,0XDE,0X4D,0XBE,0X4D,0XBE,
0X4D,0XDE,0X4D,0XDE,0X3C,0XD9,0X1A,0X2B,0X00,0X20,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X22,0XCE,0X4D,0XBD,0X4D,0XDE,0X4D,0X9C,0X4D,0X7C,0X4D,0X7C,0X4D,0X7C,
0X4D,0X7C,0X4D,0X7C,0X4D,0XBD,0X4D,0XFE,0X33,0X92,0X00,0X41,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X22,0X8C,0X55,0XFE,0X4D,0XBD,0X4D,0X9C,0X4D,0X9C,0X4D,0X9C,0X4D,0X9C,0X4D,0X9C,
0X4D,0X9C,0X4D,0X9C,0X4D,0X9C,0X4D,0XBD,0X56,0X1F,0X2B,0X71,0X00,0X20,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X11,0XA8,
0X55,0XDD,0X55,0XDD,0X55,0XBC,0X55,0XBC,0X55,0XBC,0X55,0XBC,0X55,0XBC,0X4D,0XBC,
0X4D,0XBC,0X4D,0XBC,0X4D,0XBC,0X4D,0XBC,0X4D,0XBD,0X56,0X3F,0X22,0XAD,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X18,0XE3,0X39,0XC7,0X08,0X61,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X44,0XD7,
0X5E,0X1E,0X55,0XDD,0X55,0XDD,0X55,0XDD,0X55,0XDD,0X55,0XDD,0X55,0XDC,0X65,0XFD,
0X6E,0X1D,0X6E,0X1D,0X6E,0X1D,0X6E,0X1D,0X66,0X1D,0X55,0XFD,0X55,0X9C,0X08,0XC3,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X84,0X30,0X8C,0X71,0X21,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X1A,0X2A,0X5E,0X3E,
0X55,0XFD,0X55,0XFD,0X55,0XFD,0X55,0XFD,0X55,0XFD,0X55,0XDD,0X7E,0X7D,0XF7,0XDF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0X96,0X9E,0X56,0X5F,0X33,0X50,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X73,0X8E,0XB5,0X96,0X18,0XE3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X4C,0XD7,0X5E,0X5E,
0X5E,0X1D,0X5E,0X1D,0X5E,0X1D,0X5E,0X1D,0X5E,0X1D,0X55,0XFD,0XB7,0X1E,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XBF,0X3E,0X56,0X1D,0X55,0X7A,
0X08,0X82,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X63,0X2C,0X7B,0XCF,0X31,0XA6,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X11,0X05,0X5E,0X1D,0X5E,0X3D,
0X5E,0X1D,0X5E,0X1D,0X5E,0X1D,0X5E,0X1D,0X5E,0X1D,0X55,0XFD,0XB7,0X1E,0XFF,0XFF,
0XFF,0XFF,0XF7,0XBF,0XE7,0X5F,0XFF,0XFF,0XFF,0XFF,0XBF,0X3E,0X56,0X1D,0X66,0X7F,
0X22,0X2A,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X08,0X61,0X6B,0X4D,0X9C,0XF3,0X18,0XE3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X22,0X6B,0X66,0X9F,0X66,0X3D,
0X66,0X3D,0X66,0X3D,0X66,0X3D,0X66,0X3D,0X66,0X3D,0X56,0X1D,0XB7,0X1E,0XFF,0XFF,
0XF7,0X9F,0X8C,0XDC,0X8C,0XBC,0XDF,0X1E,0XFF,0XFF,0XC7,0X5E,0X5E,0X1D,0X66,0X9F,
0X3B,0X91,0X00,0X00,0X00,0X00,0X00,0X20,0X10,0XA2,0X08,0X41,0X00,0X00,0X00,0X00,
0X18,0XC3,0X84,0X10,0X73,0XAE,0X31,0X86,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X33,0X6F,0X6E,0XBF,0X66,0X5D,
0X66,0X5D,0X66,0X5D,0X66,0X5D,0X66,0X5D,0X66,0X5D,0X5E,0X3D,0XB7,0X3E,0XFF,0XFF,
0XEF,0X7F,0X8C,0XDC,0X95,0X1C,0XE7,0X3E,0XFF,0XFF,0XC7,0X5F,0X5E,0X3D,0X6E,0X9F,
0X4C,0XD6,0X00,0X00,0X00,0X00,0X52,0XAA,0X8C,0X51,0X31,0XA6,0X00,0X00,0X00,0X00,
0X00,0X00,0X84,0X10,0X8C,0X71,0X21,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X44,0X74,0X6E,0XBF,0X6E,0X7D,
0X6E,0X7D,0X66,0X7D,0X66,0X7D,0X66,0X5D,0X66,0X5D,0X5E,0X5D,0XB7,0X3E,0XFF,0XFF,
0XFF,0XFF,0XFF,0XFF,0XFF,0XDF,0XFF,0XFF,0XFF,0XFF,0XC7,0X5F,0X66,0X5D,0X6E,0XBE,
0X5D,0X79,0X00,0X20,0X00,0X00,0X5A,0XCB,0XA5,0X14,0X42,0X08,0X00,0X00,0X00,0X00,
0X00,0X00,0X6B,0X4D,0X9C,0XD3,0X31,0XA6,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X54,0XD6,0X76,0XDF,0X6E,0X9D,
0X6E,0X9D,0X6E,0X9D,0XA6,0XFE,0XBF,0X5E,0XB7,0X5E,0XB7,0X5F,0XD7,0X9F,0XEF,0XFF,
0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XC7,0X5F,0X66,0X7D,0X6E,0XBE,
0X5D,0XDA,0X00,0X41,0X00,0X00,0X4A,0X69,0XAD,0X75,0X5A,0XCB,0X00,0X00,0X00,0X00,
0X31,0X86,0X6B,0X6D,0X94,0X92,0X21,0X24,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X54,0XF6,0X76,0XFF,0X6E,0XBE,
0X66,0X9D,0X9E,0XDE,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XE7,0XDF,0XEF,0XDF,0XEF,0XDF,0XEF,0XDF,0XEF,0XDF,0X9F,0X1E,0X6E,0X9D,0X76,0XDE,
0X65,0XDA,0X00,0X41,0X00,0X00,0X4A,0X49,0X7B,0XEF,0X63,0X0C,0X00,0X00,0X00,0X00,
0X18,0XC3,0X63,0X2C,0X84,0X30,0X21,0X24,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X4C,0XB4,0X77,0X1F,0X76,0XBE,
0X6E,0XBD,0XA7,0X1E,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XF7,0XFF,0XFF,0XFF,0XFF,0XFF,
0XC7,0X9F,0X6E,0XBE,0X76,0XDE,0X76,0XBE,0X8E,0XFE,0X86,0XFE,0X6E,0XBE,0X76,0XFE,
0X65,0XB9,0X00,0X20,0X00,0X00,0X52,0X8A,0X7B,0XEF,0X52,0X8A,0X00,0X00,0X00,0X00,
0X00,0X00,0X5A,0XEB,0X7B,0XEF,0X29,0X65,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X43,0XD0,0X7F,0X3F,0X76,0XDE,
0X6E,0XDE,0XA7,0X1E,0XFF,0XFF,0XFF,0XFF,0XCF,0XBF,0XBF,0XBF,0XFF,0XFF,0XFF,0XFF,
0XC7,0X9F,0X6E,0XDE,0X76,0XDE,0X6E,0XDE,0X86,0XFE,0X9F,0X3E,0X76,0XDE,0X7F,0X3F,
0X5D,0X57,0X00,0X00,0X21,0X04,0X39,0XE7,0XB5,0XB6,0X31,0X86,0X00,0X00,0X00,0X00,
0X00,0X00,0X6B,0X6D,0X7B,0XCF,0X18,0XC3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X32,0XAB,0X7F,0X5F,0X7E,0XFE,
0X6E,0XFE,0XA7,0X1E,0XFF,0XFF,0XFF,0XFF,0XDF,0XDF,0XC7,0XBF,0XF7,0XFF,0XFF,0XFF,
0XC7,0X9F,0X76,0XFE,0X7E,0XFE,0X76,0XFE,0X97,0X3E,0X97,0X3E,0X76,0XFE,0X7F,0X5F,
0X4C,0X32,0X00,0X00,0X31,0X65,0X9C,0XD3,0X5A,0XCB,0X5A,0XEB,0X00,0X00,0X00,0X00,
0X00,0X00,0X52,0XAA,0X73,0XAE,0X18,0XC3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X19,0X66,0X7F,0X1E,0X7F,0X1E,
0X76,0XFE,0XA7,0X3E,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XC7,0X9F,0X77,0X1E,0X7F,0X1E,0X8F,0X3E,0XAF,0X7F,0X7F,0X1E,0X7F,0X1E,0X87,0X7F,
0X2A,0XAB,0X00,0X00,0X00,0X00,0X08,0X61,0X00,0X00,0X00,0X20,0X00,0X00,0X00,0X00,
0X00,0X00,0X6B,0X4D,0XA5,0X34,0X31,0XA6,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X6D,0XF9,0X87,0X7F,
0X7F,0X1E,0XA7,0X3E,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XC7,0XBF,0X97,0X5E,0X9F,0X7E,0XB7,0X7F,0X87,0X3E,0X7F,0X3E,0X87,0X5F,0X7E,0XBC,
0X10,0XE3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X52,0X8A,0X63,0X2C,0X18,0XE3,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X3B,0X2D,0X8F,0X9F,
0X7F,0X5E,0X9F,0X3E,0XF7,0XDF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,0XFF,
0XB7,0X9F,0X87,0X5E,0X97,0X7E,0X87,0X5E,0X87,0X5E,0X87,0X5E,0X8F,0XBF,0X4C,0X52,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X18,0XC3,0X52,0X8A,0X4A,0X69,0X10,0X82,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X61,0X76,0X5A,
0X8F,0X9F,0X7F,0X3E,0X8F,0X1E,0XA7,0X5E,0XA7,0X5F,0XA7,0X7F,0XA7,0X7F,0XA7,0X7F,
0X87,0X5E,0X87,0X5E,0X87,0X5E,0X87,0X5E,0X87,0X5E,0X87,0X7F,0X87,0X5E,0X19,0X65,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X73,0X8E,0X7B,0XCF,0X52,0X8A,0X10,0XA2,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X2A,0X8B,
0X8F,0X9F,0X87,0X7F,0X7F,0X5E,0X7F,0X5E,0X7F,0X5E,0X7F,0X5E,0X7F,0X5E,0X7F,0X5E,
0X87,0X5E,0X87,0X5E,0X87,0X5E,0X87,0X5E,0X87,0X5E,0X8F,0XDF,0X4B,0XF0,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X39,0XC7,0X29,0X65,0X10,0XA2,0X00,0X20,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X4C,0X31,0X8F,0XBF,0X87,0X5F,0X87,0X5E,0X87,0X5E,0X87,0X5E,0X87,0X5E,0X87,0X5E,
0X87,0X5E,0X87,0X5E,0X87,0X5E,0X87,0X5E,0X8F,0XBF,0X65,0X76,0X00,0X20,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X54,0X93,0X8F,0XBE,0X87,0X7F,0X87,0X5E,0X87,0X5E,0X87,0X5E,0X87,0X5E,
0X87,0X5E,0X87,0X5E,0X87,0X7F,0X8F,0XBF,0X65,0XB7,0X08,0X82,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X3B,0X2D,0X7E,0XBC,0X8F,0X9F,0X8F,0X9F,0X87,0X7F,0X87,0X7F,
0X87,0X9F,0X8F,0X9F,0X87,0X1D,0X4C,0X31,0X00,0X41,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X08,0X82,0X3B,0X6E,0X65,0X97,0X6E,0X3A,0X76,0X3A,
0X6D,0XD8,0X4C,0X31,0X11,0X04,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X20,0X00,0X21,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,0X00,
0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,
0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,
0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,
0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,
0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,0X10,0X82,
};